@@ -9,13 +9,17 @@
 * @copyright  2008 stk2k, sazysoft
 */
 
-class charcoal_EncodingConverterException extends charcoal_Exception
+class EncodingConverterException extends CharcoalException
 {
 	public function __construct( $message )
 	{
 		$msg = "[message]$message";
 
 		parent::__construct( $msg );
+
+		ExceptionStack::push( $this );
 	}
 
 }
+
+return __FILE__;
\ No newline at end of file
