@@ -4,12 +4,12 @@
 *
 * PHP version 5
 *
-* @package    core
+* @package    html_objects
 * @author     stk2k <stk2k@sazysoft.com>
 * @copyright  2008 stk2k, sazysoft
 */
 
-abstract class charcoal_HTMLContainerObject extends charcoal_HTMLObject
+abstract class HTMLContainerObject extends HTMLObject
 {
 	protected $_children;
 
@@ -26,7 +26,7 @@ abstract class charcoal_HTMLContainerObject extends charcoal_HTMLObject
 	/*
 	 *	Ǥɲ
 	 */
-	public function addChild( charcoal_HTMLObject $child )
+	public function addChild( HTMLObject $child )
 	{
 		$this->_children[] = $child;
 	}
@@ -61,4 +61,20 @@ abstract class charcoal_HTMLContainerObject extends charcoal_HTMLObject
 		return $html;
 	}
 
+	/*
+	 *	
+	 */
+	public function dump( $indent = 0 )
+	{
+		$children = $this->_children;
+		foreach( $children as $c ){
+			print str_repeat('&nbsp;',$indent*4) . get_class($c) . "<BR>";
+			if ( $c instanceof HTMLContainerObject ){
+				$c->dump( $indent + 1 );
+			}
+		}
+	}
+
 }
+
+return __FILE__;
\ No newline at end of file
