@@ -9,17 +9,13 @@
 * @copyright  2008 stk2k, sazysoft
 */
 
-interface charcoal_IClassLoader
+interface IClassLoader extends IObject
 {
-
-	/*
-	 * 饹̾
-	 */
-	public function getClassLoaderName();
-
 	/*
 	 * 饹
 	 */
-	public static function loadClass( $class_name );
+	public static function loadClass( String $class_name );
 
 }
+
+return __FILE__;
\ No newline at end of file
