@@ -9,9 +9,8 @@
 * @copyright  2008 stk2k, sazysoft
 */
 
-interface charcoal_ITableModel extends charcoal_IModel
+interface ITableModel extends IModel
 {
-
 	/*
 	 *   ơ֥̾
 	 */
@@ -25,16 +24,23 @@ interface charcoal_ITableModel extends charcoal_IModel
 	/*
 	 *   ե̾
 	 */
-	public function getForeignKey( $model_name );
+	public function getForeignKey( String $model_name );
 
 	/*
 	 *   Ÿեɤ
 	 */
-	public function getExtractField( $model_name, $field );
+	public function getExtractField( String $model_name, String $field );
 
 	/*
 	 *   Ϣ
 	 */
 	public function getRelationList();
 
+	/*
+	 *   ơ֥ͭDTO
+	 */
+	public function createDTO();
+
 }
+
+return __FILE__;
\ No newline at end of file
