@@ -23,15 +23,14 @@ class ShouhinEditTask extends DatabaseTask implements ITask
 	/**
 	 * ٥Ȥ
 	 */
-	public function processEvent( IEvent $event )
+	public function processEvent( IEvent $event, TaskSnapshot $snapshot )
 	{
 		// ʤ򸡺
 		$id = $event->get( s('id') );
-		$this->shouhin = $this->findById( new ShouhinTableModel(), s($id), s('DB_TO_HTML') );
+		$this->shouhin = $this->findById( s('shouhin'), s($id), s('DB_TO_HTML') );
 
 		// ᡼򸡺
-		$model = new ManufacturerTableModel();
-		$this->manufacturer_list = $this->findAll( $model, NULL, s('DB_TO_HTML') );
+		$this->manufacturer_list = $this->findAll( s('manufacturer'), NULL, s('DB_TO_HTML') );
 
 		return b(TRUE);
 	}
